## Ver. 1.2.0 - 2016-Mar-17

Pulsar 1.2 is broadly backward compatible with the [1.1 version](./1.1.html)
with the only caveat that the ``is_async`` function is now deprecated and replaced
by the ``isawaitable`` function.
Warnings will be issued when used by client applications.

In addition, pulsar **1.2.x** is the last minor release ("major.minor.micro") to support python 3.4.
From pulsar **1.3.x**, support for python 3.4 will be dropped and the new
[async-await](https://www.python.org/dev/peps/pep-0492/#new-coroutine-declaration-syntax)
syntax will be used in the whole codebase.

# New Features
* Added ``isawaitable`` function and deprecated ``is_async`` which will be removed
  in version 1.3. Issue #203 [6a2f9e4](https://github.com/quantmind/pulsar/commit/6a2f9e427ed30c55fa2dfd2c13d7e0bf1dc1d14e)
* Verify parameter in http client. Fixes #191 [4611261](https://github.com/quantmind/pulsar/commit/46112618701e83f2c2de2d37391d2f5efe28b2ad)
* Hindi pulsar, need double check [c83e178](https://github.com/quantmind/pulsar/commit/c83e1786a7ef7a0ef9870f59e19f9b4099673d5d)

# Bug fixes and Enhancements
* Versioning supports [pep440](https://www.python.org/dev/peps/pep-0440/) for alpha and beta
  releases too [468daa2](https://github.com/quantmind/pulsar/commit/468daa2da55ac9628215b93340d19d553e451e62)
* Tidy up cython extensions. No more py2 checks. Better dev version to avoid warning
  in command line [6d369f0](https://github.com/quantmind/pulsar/commit/6d369f0a4f4defcbc3083769d2fb0082cc8badb3)
* fix [#211](https://github.com/quantmind/pulsar/issues/211) 
* Fix [#209](https://github.com/quantmind/pulsar/issues/209) 

### Examples
* Added Green Flask example applications to illustrate how to use synchronous web frameworks and
  pulsar ``greenio`` module [1855819](https://github.com/quantmind/pulsar/commit/1855819ed41a7bf67b6dba0feb39d593b480bb38)

### Test
* Links test [c80b163](https://github.com/quantmind/pulsar/commit/c80b163c6e5eeea3fbcb8af677d6e6a9369545da)
* Don't run slugify test if unidecode package is not installed. Fixes [#206](https://github.com/quantmind/pulsar/issues/206)

### Wsgi
* Check for missing suffix in the file when serving media files [bc6e04d](https://github.com/quantmind/pulsar/commit/bc6e04d805ad8579ff28f106cb1a14e4891f0ae6)

